@@ -1,7 +1,7 @@
 #! /usr/bin/env perl
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2002-2004)
+#   Copyright (C) Dr. Heinz-Josef Claes (2002-2005)
 #                 hjclaes@web.de
 #   
 #   This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
 #
 
 
-my $VERSION = '$Id: storeBackupRecover.pl 331 2004-06-06 19:57:12Z hjc $ ';
+my $VERSION = '$Id: storeBackupRecover.pl 336 2005-08-12 21:03:30Z hjc $ ';
 push @VERSION, $VERSION;
 
 
@@ -191,6 +191,7 @@ $prLog->print('-kind' => 'E',
 
 my $rt = $restoreTree;
 my $restoreTree = &absolutePath($restoreTree);
+$restoreTree = $1 if $restoreTree =~ /(.*)\/$/;  # remove trailing '/'
 
 #
 # md5CheckSum - Datei finden
@@ -214,6 +215,8 @@ else
     $backupRoot = undef;
     do
     {
+	$dir =~ s/\/\.//g;
+
 	# feststellen, ob eine .md5sum Datei vorhanden ist
 	if (-f "$dir/$checkSumFile" or -f "$dir/$checkSumFile.bz2")
 	{
@@ -277,10 +280,8 @@ my $fork = parallelForkProc->new('-maxParallel' => $noRestoreParallel,
 
 my $meta = $rcsf->getMetaVal();
 
-#my ($uncompr, @uncomprPar) = split(/\s+/, $meta{'uncompress'});
 my ($uncompr, @uncomprPar) = split(/\s+/, $$meta{'uncompress'});
 my ($cp, @cpPar) = ('cp');
-#my $postfix = $meta{'postfix'};
 my $postfix = $$meta{'postfix'};
 
 # dbm-File ffnen
@@ -300,9 +301,14 @@ my $noDirs = 0;
 my $hardLinks = 0;
 
 # Zurcksichern der Dateien
+$restoreTree =~ s/\/\.//g;
+$restoreTree = '' if $restoreTree eq '.';
 my $lrestoreTree = length($restoreTree);
 my ($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
     $size, $uid, $gid, $mode, $filename);
+#print "restoreTree = <$restoreTree>\n";
+#print "lrestoreTree = <$lrestoreTree>\n";
+#print "isFile = <$isFile>\n";
 while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 	 $size, $uid, $gid, $mode, $filename) = $rcsf->nextLine()) > 0)
 {
@@ -312,10 +318,11 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
     {
 	$f .= $postfix if ($compr eq 'c');
     }
-
+#print "from .md5CheckSums: $f\n";
     if ($restoreTree eq '' or "$restoreTree/" eq substr($f, 0, $lrestoreTree + 1)
 	or ($isFile and $restoreTree eq $f))
     {
+#print "---> restore!\n";
 	my $targetFile;
 	if ($flat)
 	{
@@ -364,7 +371,7 @@ while ((($md5sum, $compr, $devInode, $inodeBackup, $ctime, $mtime, $atime,
 		# geaendert, sondern die Datei, auf die er verweist.
 		# (dann muss lchown genommen werden -> Inkompatibilitaeten!?)
 		my $chown = forkProc->new('-exec' => 'chown',
-					  '-param' => [$uid, $gid,
+					  '-param' => ['-h', "$uid:$gid",
 						       "$targetFile"],
 					  '-outRandom' => "$tmpdir/chown-",
 					  '-prLog' => $prLog);
