@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Heinz-Josef Claes (2001-2004)
+#   Copyright (C) Heinz-Josef Claes (2001-2005)
 #                 hjclaes@web.de
 #   
 #   This program is free software; you can redistribute it and/or modify
@@ -20,13 +20,52 @@
 #
 
 
-push @VERSION, '$Id: fileDir.pl 334 2004-07-09 16:25:10Z hjc $ ';
+push @VERSION, '$Id: fileDir.pl 336 2005-08-12 21:03:30Z hjc $ ';
 
 require 'prLog.pl';
 require 'forkProc.pl';
 
 use strict;
 
+# checks if a file is a symlink and deletes it if wanted
+# return values (if not exiting):
+#               0: no symlink
+#              -1: found symlink
+############################################################
+sub checkDelSymLink
+{
+    my $file = shift;       # name of the file
+    my $prLog = shift;
+    my $delExit = shift;    # set bits:
+                            #  bit 0:  0 = do not delete
+                            #          1 = delete synlink
+                            #              if not possible, exit
+                            #  bit 1:  0 = do not exit (if exists)
+                            #          1 = exit
+
+    return 0 unless -l $file;
+
+    if ($delExit & 0x02)
+    {
+	$prLog->print('-kind' => 'E',
+		      '-str' =>
+		      ["found symbolic link at <$file>, exiting "],
+		      '-exit' => 1);
+    }
+
+    if ($delExit & 0x01)
+    {
+	$prLog->print('-kind' => 'W',
+		      '-str' => ["unlinking symbolic link <$file>"]);
+	unlink $file or
+	    $prLog->print('-kind' => 'E',
+			  '-str' => ["cannot unlink <$file>, exiting"],
+			  '-exit' => 1);
+    }
+
+    return -1;
+}
+
 
 ############################################################
 sub splitFileDir
@@ -59,7 +98,11 @@ sub absolutePath
 
     # Falls Datei selbst ein symlink ist, solange folgen, bis aufgelst
     my $file = '';
-    if (-f $dir)
+
+    
+    $dir = $ENV{'PWD'} . "/$dir" unless ($dir =~ /^\//); # relativer Pfad
+
+    if (-e $dir)
     {
 	$file = $dir;
 	while (-l $file)
@@ -80,21 +123,11 @@ sub absolutePath
 	$file = "/$file";
     }
 
-    my $oldDir = `/bin/pwd`;
-    my $ret;
-    chomp $oldDir;
-    if (chdir $dir)
-    {
-	my $absDir = `/bin/pwd`;
-	chop $absDir;
-	chdir $oldDir;
+    my $ret = (-e "$dir$file") ? "$dir$file" : undef;
+    $ret =~ s/\/\//\//g;    # // -> /
+    $ret =~ s/\/\.\//\//g;  # /./ -> /
+    $ret =~ s/(.*.)\/$/$1/; # remove trailing /
 
-	$ret = "$absDir$file";
-    }
-    else
-    {                # Directory existiert nicht
-	$ret = undef;
-    }
     if (@main::absolutePathCache > 100)
     {
 	my $del = shift @main::absolutePathCache;   # delete oldest
@@ -146,6 +179,8 @@ sub substractPath
 
     $pathLong =~ s/\/+$//;      # remove trailing /
     $pathShort =~ s/\/+$//;     # remove trailing /
+    $pathLong =~ s/\/\//\//g;   # // -> /
+    $pathShort =~ s/\/\//\//g;  # // -> /
 
     my $relPath;
     if ($pathShort eq '/')
@@ -321,7 +356,7 @@ sub new
 		    '-prLogWarn'           => 'W',
 		    '-exitIfError'         => 1, # Errorcode bei Fehler
 		    '-verbose'             => undef,
-		    '-ignoreReadError'     => 'no',
+		    '-ignoreReadError'     => 'no', # no, yes, onlyPrintMessage
 		    '-printDepth'          => 'no',
 		    '-printDepthPrlogKind' => 'I'
 		    );
@@ -490,12 +525,16 @@ sub readDir
 			   "check your source and clean your backup!"],
 			  '-exit' => $exit);
 	}
-	else
+	elsif ($ignoreReadError eq 'onlyPrintMessage')
 	{
 	    $prLog->print('-kind' => $prLogErr,
 			  '-str' => ["cannot opendir <$dir>"]);
 	    return;
 	}
+	else
+	{
+	    return;
+	}
     }
 
     my $entry;
