@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Heinz-Josef Claes (2000)
+#   Copyright (C) Heinz-Josef Claes (2000-2005)
 #                 hjclaes@web.de
 #   
 #   This program is free software; you can redistribute it and/or modify
@@ -20,10 +20,11 @@
 #
 
 
-push @VERSION, '$Id: humanRead.pl,v 1.2 2001/03/14 12:59:37 hjc Exp $ ';
+push @VERSION, '$Id: humanRead.pl 336 2005-08-12 21:03:30Z hjc $ ';
 
 use strict;
 
+######################################################################
 # Stellt eine Zahl als dreistellig + Zeichen dar, analog `df -h`
 sub humanReadable
 {
@@ -36,12 +37,12 @@ sub humanReadable
 	my $i;
 	for ($i = 0 ; $i < @type - 1; $i++, $s /= 1024.)
 	{
-	    if ($s < 9)
+	    if ($s < 10)
 	    {
 		push @ret, sprintf("%.1f%s", $s, $type[$i]);
 		goto nextNumber;
 	    }
-	    elsif ($s < 999)
+	    elsif ($s < 999.5)
 	    {
 		push @ret, sprintf("%3.0f%s", $s, $type[$i]);
 		goto nextNumber;
@@ -53,3 +54,28 @@ sub humanReadable
 
     return @ret;
 }
+
+
+######################################################################
+sub packwithLen
+{
+    my $format = shift;  # pack format string, rest in @_ is argument to pack
+
+    my $entry = pack($format, @_);
+    return pack('S', length($entry)) . $entry;
+}
+
+
+######################################################################
+sub unpackwithLen
+{
+    my $format = shift;
+    my $packedData = shift;
+
+    my $len = unpack('S', $packedData);
+    # returns next entries of packedData und the unpacked values
+    return (substr($packedData, $len + 2),
+	    unpack($format, substr($packedData, 2)));
+}
+
+1
