@@ -1,7 +1,7 @@
 # -*- perl -*-
 
 #
-#   Copyright (C) Dr. Heinz-Josef Claes (2001-2004)
+#   Copyright (C) Dr. Heinz-Josef Claes (2001-2005)
 #                 hjclaes@web.de
 #   
 #   This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 #   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
 
-push @VERSION, '$Id: storeBackupLib.pl 335 2004-07-23 03:56:18Z hjc $ ';
+push @VERSION, '$Id: storeBackupLib.pl 336 2005-08-12 21:03:30Z hjc $ ';
 
 use strict;
 
@@ -1751,6 +1751,7 @@ sub new
     my $compressMD5File = $self->{'compressMD5File'};
 
     local *FILE;
+    &::checkDelSymLink("$checkSumFile.notFinished", $prLog, 0x01);
     open(FILE, "> $checkSumFile.notFinished") or
 	$prLog->print('-kind' => 'E',
 		      '-str' => ["cannot open <$checkSumFile.notFinished>"],
@@ -1759,6 +1760,7 @@ sub new
     print FILE "$$\n";
     close(FILE);
 
+    &::checkDelSymLink("$checkSumFile.info", $prLog, 0x01);
     open(FILE, "> $checkSumFile.info") or
 	$prLog->print('-kind' => 'E',
 		      '-str' => ["cannot open <$checkSumFile.info>"],
@@ -1776,6 +1778,7 @@ sub new
     if ($self->{'compressMD5File'} eq 'yes')
     {
 	$self->{'checkSumFile'} = "$checkSumFile.bz2";
+	&::checkDelSymLink("$checkSumFile.bz2", $prLog, 0x01);
 	open(FILE, "| bzip2 > $checkSumFile.bz2") or
 	    $prLog->print('-kind' => 'E',
 			  '-str' => ["cannot open <$checkSumFile.bz2>"],
@@ -1784,6 +1787,7 @@ sub new
     }
     else
     {
+	&::checkDelSymLink($checkSumFile, $prLog, 0x01);
 	open(FILE, "> $checkSumFile") or
 	    $prLog->print('-kind' => 'E',
 			  '-str' => ["cannot open <$checkSumFile>"],
@@ -1850,8 +1854,9 @@ sub write
     local *FILE;
     *FILE = $self->{'CHECKSUMFILE'};
 
-    $filename =~ s/\\/\\5C/og;    # '\\' durch Hexzahl ausdrcken
-    $filename =~ s/\n/\\0A/sog;   # '\n' durch Hexzahl ausdrcken
+    $filename =~ s/\\/\\5C/og;    # '\\' stored as \5C
+    $filename =~ s/\n/\\0A/sog;   # '\n' stored as \0A
+    $filename =~ s/^\///o;        # remove leading slash if it exists
 
     print FILE "$md5sum $compr $dev-$inode $inodeBackup $ctime $mtime $atime",
     " $size $uid $gid $mode $filename\n";
@@ -2277,6 +2282,29 @@ sub newFile
 }
 
 
+########################################
+sub newDir
+{
+    my $self = shift;
+
+    my $d = shift;
+
+    my $dirToIndex = $self->{'dirToIndex'};
+    if (exists($$dirToIndex{$d}))
+    {
+	return $$dirToIndex{$d};
+    }
+    else
+    {
+	my $indexToDir = $self->{'indexToDir'};
+	$$dirToIndex{$d} = $self->{'count'};
+	$$indexToDir{$self->{'count'}} = $d;
+
+	return $self->{'count'}++;
+    }
+}
+
+
 ########################################
 sub replaceIndex
 {
@@ -2290,6 +2318,18 @@ sub replaceIndex
 }
 
 
+########################################
+sub index2dir
+{
+    my $self = shift;
+
+    my $index = shift;
+
+    my $indexToDir = $self->{'indexToDir'};
+    return $$indexToDir{$index};
+}
+
+
 ########################################
 sub setIndex
 {
